summaryrefslogtreecommitdiff
path: root/plugingui/nativewindow_win32.cc
diff options
context:
space:
mode:
Diffstat (limited to 'plugingui/nativewindow_win32.cc')
-rw-r--r--plugingui/nativewindow_win32.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/plugingui/nativewindow_win32.cc b/plugingui/nativewindow_win32.cc
index 871bafe..c6d3426 100644
--- a/plugingui/nativewindow_win32.cc
+++ b/plugingui/nativewindow_win32.cc
@@ -8,20 +8,20 @@
****************************************************************************/
/*
- * This file is part of DrumGizmo.
+ * This file is part of CamSync.
*
* DrumGizmo is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* DrumGizmo is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with DrumGizmo; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
*/
#include "nativewindow_win32.h"
@@ -289,7 +289,7 @@ GUI::NativeWindowWin32::NativeWindowWin32(GUI::Window *window)
wcex.hbrBackground = NULL;//(HBRUSH) COLOR_BACKGROUND + 1;
// }
- wcex.lpszClassName = m_className = strdup("DrumGizmoClass");
+ wcex.lpszClassName = m_className = strdup("CamSyncClass");
RegisterClassEx(&wcex);
@@ -8,20 +8,20 @@
*
- * DrumGizmo is free software; you can redistribute it and/or modify
+ * CamSync is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -8,20 +8,20 @@
* (at your option) any later version.
*
- * DrumGizmo is distributed in the hope that it will be useful,
+ * CamSync is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -8,20 +8,20 @@
*
* You should have received a copy of the GNU General Public License
- * along with DrumGizmo; if not, write to the Free Software
+ * along with CamSync; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
*/